;; Generated package description from git-modes.el  -*- no-byte-compile: t -*-
(define-package "git-modes" "1.4.8.0.20260101.183425" "Major modes for editing Git configuration files" '((emacs "26.1") (compat "30.1")) :commit "c3faeeea1982786f78d8c38397dec0f078eaec84" :authors '(("Sebastian Wiesner" . "lunaryorn@gmail.com") ("Rüdiger Sonderfeld" . "ruediger@c-plusplus.net") ("Jonas Bernoulli" . "emacs.git-modes@jonas.bernoulli.dev")) :maintainer '("Jonas Bernoulli" . "emacs.git-modes@jonas.bernoulli.dev") :keywords '("convenience" "vc" "git") :url "https://github.com/magit/git-modes")
